## Overview

This Python package provides code regarding the RDG networks project.

[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Python Version](https://img.shields.io/badge/python-3.6%2B-blue.svg)](https://www.python.org/downloads/)

## Table of Contents

- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
- [Configuration](#configuration)
- [License](#license)
- [Contact](#contact)

## Features

- **generate_line_segments:** Function that determines the linesegments of a RDG network.
- **generate_line_network:** Function that makes the underlying network of the linesegments.
- **get_intersection_segments:** Function that determines the intersection segments of a RDG network.
- **generate_line_segments_dynamic:** Function that determines the segments of a dynamic RDG network (with increasing linelengths in time).
- **draw_segments:** Function that draws the segments.


## Installation
You can install the package using pip:

```bash
pip install RDG-networks
```

## Usage
To use the package, import the relevant script from the functions folder based on the algorithm you'd like to apply.

## Configuration
No specific configuration is required.

## License
All Rights Reserved

The following code and its accompanying documentation are the property of Martijn (Niek) Mooij. All rights are reserved. No part of this code may be reproduced, distributed, or transmitted in any form or by any means, including photocopying, recording, or other electronic or mechanical methods, without the prior written permission of the author, except in the case of brief quotations embodied in critical reviews and certain other noncommercial uses permitted by copyright law. For permission requests, write to the author at mooij.niek@gmail.com.

Copyright 2024 Niek Mooij

## Contact
You can contact me at mooij.niek@gmail.com for any questions or suggestions.